<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 * @return array An array of default values
 */

function mega_tour_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$mega_tour_pro_default_options = array(
		'search_icon_in_primary_menu_enable' => true,
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#F38625',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'mega-tour-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,service,blog_featured,popular_destination,about,team,featured,package,cta,gallery,testimonial,partner,blog,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'mega-tour-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		'topbar_section_enable'			=>false,
		'topbar_social_menu_enable'		=>false,
		'topbar_contact_number'			=> __('(123) 456 4521','mega-tour-pro'),
		'topbar_email'					=> __('info@megatour.com','mega-tour-pro'),


		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'View Details', 'mega-tour-pro' ),
		'slider_video_label'			=> esc_html__( 'Watch video', 'mega-tour-pro' ),


		//service

		'service_title'				=> esc_html('Make Successful Business', 'mega-tour-pro'),
		// trip search
		'trip_search_title_enable'	=> true,
		'trip_search_enable'	=> (class_exists( 'WP_Travel' )) ? true : false,
		'service_btn_label'	=>esc_html__('Learn more','mega-tour-pro'),
		'trip_search_title'		=> esc_html__('Search Destination','mega-tour-pro'),

		// featured
		'featured_section_enable'		=> true,
		'featured_cat_meta_image_enable'=>false,
		'featured_sub_title'			=> esc_html__('Tour Types','mega-tour-pro'),
		'featured_title'				=>esc_html('Discover By Interest',',ega-tour-pro'),
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_btn_title'			=> esc_html__( 'Discover By Interests', 'mega-tour-pro' ),
		'featured_read_more_btn_title'	=> esc_html__('Explore More', 'mega-tour-pro'),

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_column_type'		=> 4,
		'popular_destination_count'				=> 4,
		'popular_destination_title'				=> esc_html__( 'Popular Destinations', 'mega-tour-pro' ),
		'popular_destination_sub_title'			=> esc_html__('Where To Go','mega-tour-pro'),
		'popular_destination_btn_label'			=> esc_html__( 'Let’s Travel Now', 'mega-tour-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_section_counter_enable'	=> false,
		'about_content_type'			=> 'page',
		'about_bg_image'				=> esc_url(get_template_directory_uri().'/assets/uploads/business-counter.jpg' ),
		'about_title'					=> esc_html__( 'About Us', 'mega-tour-pro' ),
		'about_sub_title'				=> esc_html__( 'Who we are', 'mega-tour-pro' ),
		'about_description'				=> esc_html__( 'Between the many mouths to feed, entry to myriad attractions and school holiday price hikes, traveling with kids can quickly add up. Follow these top tips to make your hard-earned cash go further as you and your brood explore the world...', 'mega-tour-pro' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'mega-tour-pro' ),

		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_count'					=> 2,
		'package_title'					=> esc_html__( 'Recommended Packages', 'mega-tour-pro' ),
		'package_sub_title'				=> esc_html__('Tour Types', 'mega-tour-pro'),
		'package_btn_title'				=> esc_html__( 'Book This Package', 'mega-tour-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,

		// gallery
		'gallery_section_enable'	=> true,
		'gallery_content_type'		=> 'category',
		'gallery_sub_title'			=> esc_html__( 'Our Gallery', 'mega-tour-pro' ),
		'gallery_title'				=> esc_html__( 'Moment to Remember', 'mega-tour-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_show_widget_enable'		=> false,
		'blog_social_menu_enable'		=> true,
		'blog_content_type'				=> 'recent',
		'blog_sub_title'				=> esc_html__('OUR BLOG', 'mega-tour-pro'),
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Read Our Travel Blog', 'mega-tour-pro' ),
		'blog_btn_title'				=> esc_html__( 'Read All Articles', 'mega-tour-pro' ),

		//cta
		'cta_section_enable' 			=>true,
		'cta_sub_title'					=>esc_html__('Call To Action', 'mega-tour-pro'),
		'cta_title'						=>esc_html__('Travel is a cure to the mind', 'mega-tour-pro'),
		'cta_content_type'				=> 'post',
		'cta_read_more'					=>esc_html__('Learn More About It', 'mega-tour-pro'),
		'cta_background_image'			=> esc_url(get_template_directory_uri().'/assets/uploads/call-to-action.jpg' ),

		// partner
		'partner_section_enable'			=> true,
		'partner_bg_image'					=> esc_url(get_template_directory_uri().'/assets/uploads/our-partners-bg.jpg' ),
		'partner_auto_play'					=> false,
		'partner_content_type'				=> 'category',
		'partner_count'						=> 3,
		'partner_sub_title'					=> esc_html__( 'Last Minute', 'mega-tour-pro' ),
		'partner_title'						=> esc_html__( 'View Details', 'mega-tour-pro' ),

		// testimonial
		'testimonial_title'				=> esc_html__( 'We Help You to Create Adventure of Life', 'mega-tour-pro' ),
		'testimonial_sub_title'			=> esc_html__( 'TESTIMONIALS', 'mega-tour-pro' ),
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 8,

		//team
		'team_title'					=> esc_html__('Meet Our Team', 'mega-tour-pro' ),
		'team_count'					=> 4,
		'team_content_type'				=> 'custom',
		'team_section_enable'			=> true,

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Keep in touch', 'mega-tour-pro' ),
		'subscription_title'			=> esc_html__( 'Travel with us!', 'mega-tour-pro' ),
		'subscription_bg_image'			=> esc_url(get_template_directory_uri().'/assets/uploads/subscribe-us.jpg'),
		'subscription_business_bg_image'=> esc_url(get_template_directory_uri().'/assets/uploads/business-subscribe-us.jpg'),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'mega-tour-pro' ),

		//Blog Featured
		'blog_featured_section_enable'	=> true,
		'blog_featured_content_type'	=> 'post',
		'blog_featured_count'			=> 3,

	);

	$output = apply_filters( 'mega_tour_pro_default_theme_options', $mega_tour_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}