<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'mega_tour_pro_about_section', array(
	'title'             => esc_html__( 'About Us','mega-tour-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_about_panel_enable',
) );

// About Section enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// About sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us .wrapper .entry-header p.subtitle',
		'settings'            => 'mega_tour_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_about_sub_title_partial',
    ) );
}

// About content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_enable',
	'choices'			=> mega_tour_pro_about_content_type(),
) );

// About pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'choices'			=> mega_tour_pro_page_choices(),
	'active_callback'	=> 'mega_tour_pro_is_about_section_content_page_enable',
) ) );

// About posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'choices'			=> mega_tour_pro_post_choices(),
	'active_callback'	=> 'mega_tour_pro_is_about_section_content_post_enable',
) ) );

// ABOUT trips drop down chooser control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_content_trip]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[about_content_trip]', array(
	'label'             => esc_html__( 'Select Trip', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'choices'			=> mega_tour_pro_trip_choices(),
	'active_callback'	=> 'mega_tour_pro_is_about_section_content_trip_enable',
) ) );

// About title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .wrapper .entry-header h2.entry-title',
		'settings'            => 'mega_tour_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_about_title_partial',
		) );
	}


// about description setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// about btn title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'mega_tour_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[about_btn_title]', array(
		'selector'            => 'div#about-us-read-more a',
		'settings'            => 'mega_tour_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_about_btn_title_partial',
		) );
	}

	// about btn link setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
	) );
	
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_video_url]', array(
'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[about_video_url]', array(
	'label'           	=> esc_html__( 'Video URL', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_about_section',
	'active_callback' 	=> 'mega_tour_pro_is_about_video_section_enable',
	'type'				=> 'url',
) );

//about image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'About Image', 'mega-tour-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 650, 700 ),
		'section'     		=> 'mega_tour_pro_about_section',
		'active_callback'	=> 'mega_tour_pro_is_about_section_content_custom_enable',
) ) );
// About content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_section_counter_enable]', array(
	'default'			=> 	$options['about_section_counter_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[about_section_counter_enable]', array(
	'label'             => esc_html__( 'Enable Counter', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_about_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// about Backgroung image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_bg_image]', array(
	'default'           =>$options['about_bg_image'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[about_bg_image]',
		array(
		'label'       		=> esc_html__( 'About Background Image', 'mega-tour-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 1920, 600 ),
		'section'     		=> 'mega_tour_pro_about_section',
		'active_callback'	=> 'mega_tour_pro_is_third_design_enable',
) ) );

for($i = 1; $i<=4 ; $i ++) :
	// About counter control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_counter_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[about_counter_'.$i.']', array(
		'label'             => sprintf(esc_html__( 'Counter %d', 'mega-tour-pro' ), $i),
		'section'           => 'mega_tour_pro_about_section',
		'active_callback'   => 'mega_tour_pro_is_about_section_counter_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'style' => 'width: 100px;'
			),
	) );

	// about counter title setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[about_counter_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'refresh',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[about_counter_title_'.$i.']', array(
		'label'           	=> sprintf(esc_html__( 'Counter Title %d', 'mega-tour-pro' ),$i),
		'section'        	=> 'mega_tour_pro_about_section',
		'active_callback' 	=> 'mega_tour_pro_is_about_section_counter_enable',
		'type'				=> 'text',
	) );
endfor;