<?php
/**
 * Call To Action section
 *
 * This is the template for the content of Call To Action section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_cta_section' ) ) :
    /**
    * Add Call To Action section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_cta_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if Call To Action is enabled on frontpage
        $cta_enable = apply_filters( 'mega_tour_pro_section_status', true, 'cta_section_enable' );
        
        if($options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design'){
            $cta_enable = false;
        }

        if ( true !== $cta_enable ) {
            return false;
        }

        // Get Call To Action section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_cta_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Call To Action section now.
        mega_tour_pro_render_cta_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_cta_section_details' ) ) :
    /**
    * Call To Action section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input Call To Action section details.
    */
    function mega_tour_pro_get_cta_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        $cta_content_type  = $options['cta_content_type']; // Call To Action content type
        $cta_count = ! empty( $options['cta_count'] ) ? $options['cta_count'] : 1; // Call To Action Count
        
        $content = array();
        switch ( $cta_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'             => 'page',
                    'posts_per_page'        => 1,
                    'p'                     => $page_id,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $page_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $page_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                $custom['title']    = $options['cta_title'];
                $custom['excerpt']  = !empty($options['cta_description'])? $options['cta_description'] : '';
                $custom['url']      = $options['cta_btn_link'];
                array_push( $content, $custom );
            break;

            default:
            break;
        }
        if($options['cta_content_type'] != 'custom'):
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_tour_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Call To Action section content details.
add_filter( 'mega_tour_pro_filter_cta_section_details', 'mega_tour_pro_get_cta_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_cta_section' ) ) :
  /**
   * Start Call To Action section
   *
   * @return string Call To Action content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_cta_section( $content_details = array() ) {
        $options    = mega_tour_pro_get_theme_options();
        $btn_label  = $options['cta_read_more'];
        $sub_title  = $options['cta_sub_title'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="mega_tour_pro_cta_section">
             <div id="call-to-action" class="relative page-section" style="background-image: url(<?php echo $options['cta_background_image']; ?>);">
                <div class="overlay"></div>
                <div class="wrapper">
                    <header class="entry-header">
                        <p class="subtitle"><?php echo esc_html($sub_title); ?></p>
                        <h2 class="entry-title"><?php echo esc_html($content_details['title']); ?></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo wp_kses_post($content_details['excerpt']); ?></p>
                    </div><!-- .entry-content -->

                    <div class="read-more">
                        <a href="<?php echo esc_url($content_details['url']); ?>" class="btn"><?php echo esc_html($btn_label); ?></a>
                    </div>
                </div>
            </div><!-- #call-to-action -->  
        </div>
           
    <?php }
endif;