<?php
/**
 * Featured section
 *
 * This is the template for the content of Featured section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_featured_section' ) ) :
    /**
    * Add Featured section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_featured_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if Featured is enabled on frontpage
        $featured_enable = apply_filters( 'mega_tour_pro_section_status', true, 'featured_section_enable' );
        
        if($options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design'){
            $featured_enable = false;
        }

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get Featured section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_featured_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Featured section now.
        mega_tour_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_featured_section_details' ) ) :
    /**
    * Featured section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input Featured section details.
    */
    function mega_tour_pro_get_featured_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();
        
        $featured_content_type  = $options['featured_content_type']; // Content type.
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 4; // Featured Post Count
        $content = array();
        switch ( $featured_content_type ) {
        	
            case 'category':
                $cat_ids = array();
                for ( $i = 1; $i <= $featured_count; $i++ ) {

                    if ( ! empty( $options['featured_content_category_' . $i] ) ){
                        $page_post['id']      = $options['featured_content_category_' . $i];
                        $terms = get_term_by( 'id',  $page_post['id'], 'category' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'category' );
                            $page_post['count']   = $terms->count;
                            $page_post['image'] = ! empty( $options['featured_background_image_' . $i] ) ? $options['featured_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        endif;
                    }
                    if ( ! empty(  $options['featured_content_category_' . $i] ) )
                        array_push( $content, $page_post );
                }                     
            break;

            case 'trip-types': // trip-types
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_ids = array();
                

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_trip_types_' . $i] ) ){
                        $page_post['id']      = $options['featured_content_trip_types_' . $i];

                        if ( $options['featured_cat_meta_image_enable'] ) :
                            $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        else :
                            $page_post['image'] = ! empty( $options['featured_background_image_' . $i] ) ? $options['featured_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        endif;

                        $terms = get_term_by( 'id',  $page_post['id'], 'itinerary_types' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'itinerary_types' );
                            $page_post['count']   = $terms->count;
                            $page_post['rating']  = mega_tour_pro_average_post_rating($page_post['id'],'itinerary_types');
                        endif;
                    }
                    if ( ! empty(  $options['featured_content_trip_types_' . $i] ) )
                        array_push( $content, $page_post );
                }
                     
            break;

            case 'destination': //Destination
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                    
                $cat_ids = array();
                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_destination_' . $i] ) ){
                        $page_post['id']      = $options['featured_content_destination_' . $i];

                        if ( $options['featured_cat_meta_image_enable'] ) :
                            $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        else :
                            $page_post['image'] = ! empty( $options['featured_background_image_' . $i] ) ? $options['featured_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        endif;

                        $terms = get_term_by( 'id',  $page_post['id'], 'travel_locations' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'travel_locations' );
                            $page_post['count']   = $terms->count;
                            $page_post['rating']  = mega_tour_pro_average_post_rating($page_post['id'],'travel_locations');
                        endif;
                    }

                    if ( ! empty(  $options['featured_content_destination_' . $i] ) )
                        array_push( $content, $page_post );
                }   

            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_ids = array();
                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_activity_' . $i] ) ){
                        $page_post['id']      = $options['featured_content_activity_' . $i];

                        if ( $options['featured_cat_meta_image_enable'] ) :
                            $cat_image = get_term_meta( $page_post['id'], 'wp_travel_trip_type_image_id', true);
                            $page_post['image'] = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        else :
                            $page_post['image'] = ! empty( $options['featured_background_image_' . $i] ) ? $options['featured_background_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                        endif;

                        $terms = get_term_by( 'id',  $page_post['id'], 'activity' );

                        if ( ! empty( $terms ) && !is_wp_error($terms)) :
                            $page_post['title']   = $terms->name;
                            $page_post['url']     = get_term_link( $page_post['id'], 'activity' );
                            $page_post['count']   = $terms->count;
                            $page_post['rating']  = mega_tour_pro_average_post_rating($page_post['id'],'activity');
                        endif;
                    }

                    if ( ! empty(  $options['featured_content_activity_' . $i] ) )
                        array_push( $content, $page_post );
                }  
                   
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Featured section content details.
add_filter( 'mega_tour_pro_filter_featured_section_details', 'mega_tour_pro_get_featured_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_featured_section' ) ) :
  /**
   * Start Featured section
   *
   * @return string Featured content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_featured_section( $content_details = array() ) {
        $options                        = mega_tour_pro_get_theme_options();
        $featured_content_type          = $options['featured_content_type'];
        $featured_sub_title             = ! empty( $options['featured_sub_title'] ) ? $options['featured_sub_title'] : ' ';
        $featured_btn_link              = ! empty( $options['featured_btn_link'] ) ? $options['featured_btn_link'] : '#';
        $featured_btn_title             = ! empty( $options['featured_btn_title'] ) ? $options['featured_btn_title'] : esc_html__( 'Discover all packages', 'mega-tour-pro' );
        $featured_title                 = ! empty( $options['featured_title'] ) ? $options['featured_title'] : esc_html__( 'Discover By Interests', 'mega-tour-pro' );
        $featured_read_more_btn_title   = ! empty( $options['featured_read_more_btn_title'] ) ? $options['featured_read_more_btn_title'] : esc_html__( 'Explore More', 'mega-tour-pro' );
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="mega_tour_pro_featured_section">
            <div id="featured-packages" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header-wrapper clear">
                        <div class="section-header">
                            <p class="subtitle"><?php 
                            echo esc_html($featured_sub_title); ?></p>
                            <h2 class="section-title"><?php echo esc_html($featured_title); ?></h2>
                        </div><!-- .section-header -->

                        <?php if(!empty($featured_btn_title) && !empty($featured_btn_link)): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url($featured_btn_link); ?>" class="btn"><?php echo esc_html($featured_btn_title); ?></a>
                        </div><!-- .read-more -->
                        <?php endif; ?>

                    </div><!-- .section-header-wrapper -->

                    <div class="featured-package-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php foreach($content_details as $content): ?>
                        <article>
                            <div class="featured-image" style="background-image: url(<?php echo esc_url($content['image']); ?>);">
                                <div class="overlay"></div>

                                <?php if(!empty($featured_read_more_btn_title)):?>
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn">
                                        <?php echo esc_html($featured_read_more_btn_title); ?>
                                    </a>
                                <?php endif; ?>

                            </div><!-- .featured-image -->
                            <div class="entry-container">

                            <?php if ( ( $featured_content_type != 'category') && class_exists('WP_Travel') ) :  ?>
                                <?php if ( mega_tour_pro_wptravel_tab_show_in_menu( 'reviews' ) && isset($content['rating'])) : ?>
                                    <div class="wp-travel-average-review"
                                        title="<?php printf( esc_attr__( 'Rated %s out of 5', 'mega-tour-pro' ), $content['rating'] ); ?>">
                                        <span style="width:<?php echo esc_attr( ( $content['rating'] / 5 ) * 100 ); ?>%">
                                            <strong itemprop="ratingValue"
                                                class="rating"><?php echo esc_html( $content['rating'] ); ?></strong>
                                            <?php printf( esc_html__( 'out of %1$s5%2$s', 'mega-tour-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
                                        </span>
                                    </div>
                                <?php endif;
                             endif; ?>
                                
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    <?php 
                                    echo sprintf('<p>%d&nbsp;%s</p>',esc_html($content['count']), __('Tour Available','mega-tour-pro'));
                                    ?>
                                </header>
                            </div><!-- .entry-container -->
                        </article>

                        <?php endforeach; ?>
                    </div><!-- .featured-package-slider -->
                </div><!-- .wrapper -->
            </div><!-- #featured-packages -->

        </div>
        
    <?php }
endif;