<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_team_section() {
        $options = mega_tour_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'mega_tour_pro_section_status', true, 'team_section_enable' );

        
        if($options['home_layout'] != 'third-design' || $options['home_layout'] == 'fourth-design'){
            $team_enable = false;
        }

        if ( true !== $team_enable) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        mega_tour_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input team section details.
    */
    function mega_tour_pro_get_team_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 4;
        $content = array();
        switch ( $team_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $team_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $team_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $team_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['image']        = ! empty( $options['team_image_' . $i] ) ? $options['team_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $custom['title']        = ! empty( $options['team_author_' . $i] ) ? $options['team_author_' . $i] : '';
                    $custom['url']          = '#';
                    $custom['position']     = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';

                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;
            
            default:
            break;
        }

        if ( 'custom' !== $team_content_type ) {
            // Run The Loop.
            
            $query = new WP_Query( $args );
            $i = 1;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['author']    = ( 'category' !== $team_content_type && ! empty( $author[$i] ) ) ? $author[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $page_post['position']  = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';


                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'mega_tour_pro_filter_team_section_details', 'mega_tour_pro_get_team_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_team_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();

        $team_title       = ! empty( $options['team_title'] ) ? $options['team_title'] : esc_html__( 'We Help You to Create Adventure of Life', 'mega-tour-pro' );
        $team_description = ! empty( $options['team_description'] ) ? $options['team_description'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="mega_tour_pro_team_section">
             <div id="business-team" class="relative page-section">
                <div class="wrapper">
                    <div class="business-section-header">
                        <h2 class="business-section-title"><?php echo esc_html($team_title); ?></h2>
                        <p class="business-section-subtitle"><?php echo wp_kses_post($team_description); ?></p>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content clear col-4">

                    <?php foreach($content_details as $i => $content): ?>    
                        <article>
                            <div class="business-team-item">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="business-team-<?php echo $i+1; ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html($content['position']); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .business-team-item -->
                        </article>
                    <?php endforeach; ?>
                    
                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-team -->
        </div>
           

    <?php }
endif;
